@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -258,10 +258,6 @@ void vpanic ( const HChar* str )
 /*--- vex_printf                                        ---*/
 /*---------------------------------------------------------*/
 
-/* This should be the only <...> include in the entire VEX library.
-   New code for vex_util.c should go above this point. */
-#include <stdarg.h>
-
 SizeT vex_strlen ( const HChar* str )
 {
    SizeT i = 0;
@@ -609,18 +605,25 @@ static void add_to_vg_sprintf_buf ( HChar c )
    *vg_sprintf_ptr++ = c;
 }
 
-UInt vex_sprintf ( HChar* buf, const HChar *format, ... )
+UInt vex_vsprintf ( HChar* buf, const HChar* format, va_list vargs )
 {
-   Int ret;
-   va_list vargs;
+   UInt ret;
 
    vg_sprintf_ptr = buf;
+   ret = vprintf_wrk(add_to_vg_sprintf_buf, format, vargs);
+   add_to_vg_sprintf_buf('\0');
+
+   vassert(vex_strlen(buf) == ret);
+   return ret;
+}
+
+UInt vex_sprintf ( HChar* buf, const HChar *format, ... )
+{
+   UInt ret;
+   va_list vargs;
 
    va_start(vargs,format);
-
-   ret = vprintf_wrk ( add_to_vg_sprintf_buf, format, vargs );
-   add_to_vg_sprintf_buf(0);
-
+   ret = vex_vsprintf(buf, format, vargs);
    va_end(vargs);
 
    vassert(vex_strlen(buf) == ret);
