@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -162,46 +162,20 @@ typedef
 #define VEX_S390X_MODEL_UNKNOWN  19     /* always last in list */
 #define VEX_S390X_MODEL_MASK     0x3F
 
-#define VEX_HWCAPS_S390X_LDISP (1<<6)   /* Long-displacement facility */
-#define VEX_HWCAPS_S390X_EIMM  (1<<7)   /* Extended-immediate facility */
-#define VEX_HWCAPS_S390X_GIE   (1<<8)   /* General-instruction-extension facility */
-#define VEX_HWCAPS_S390X_DFP   (1<<9)   /* Decimal floating point facility */
-#define VEX_HWCAPS_S390X_FGX   (1<<10)  /* FPR-GR transfer facility */
-#define VEX_HWCAPS_S390X_ETF2  (1<<11)  /* ETF2-enhancement facility */
-#define VEX_HWCAPS_S390X_STFLE (1<<12)  /* STFLE facility */
-#define VEX_HWCAPS_S390X_ETF3  (1<<13)  /* ETF3-enhancement facility */
-#define VEX_HWCAPS_S390X_STCKF (1<<14)  /* STCKF facility */
-#define VEX_HWCAPS_S390X_FPEXT (1<<15)  /* Floating point extension facility */
-#define VEX_HWCAPS_S390X_LSC   (1<<16)  /* Conditional load/store facility */
-#define VEX_HWCAPS_S390X_PFPO  (1<<17)  /* Perform floating point ops facility */
-#define VEX_HWCAPS_S390X_VX    (1<<18)  /* Vector facility */
-#define VEX_HWCAPS_S390X_MSA5  (1<<19)  /* Message-security-assistance facility 5 */
-#define VEX_HWCAPS_S390X_MI2   (1<<20)  /* Miscellaneous-instruction-extensions facility 2 */
-#define VEX_HWCAPS_S390X_LSC2  (1<<21)  /* Conditional load/store facility2 */
-#define VEX_HWCAPS_S390X_VXE   (1<<22)  /* Vector-enhancements facility */
-#define VEX_HWCAPS_S390X_NNPA  (1<<23)  /* NNPA facility */
-#define VEX_HWCAPS_S390X_DFLT  (1<<24)  /* Deflate-conversion facility */
-#define VEX_HWCAPS_S390X_VXE2  (1<<25)  /* Vector-enhancements facility 2 */
-#define VEX_HWCAPS_S390X_VXD   (1<<26)  /* Vector packed-decimal facility */
-#define VEX_HWCAPS_S390X_MSA   (1<<27)  /* Message-security assist */
-#define VEX_HWCAPS_S390X_MSA4  (1<<28)  /* Message-security-assist extension 4 */
-#define VEX_HWCAPS_S390X_MSA8  (1<<29)  /* Message-security-assist extension 8 */
-#define VEX_HWCAPS_S390X_MSA9  (1<<30)  /* Message-security-assist extension 9 */
+#define VEX_HWCAPS_S390X_VX    (1 << 6)  /* Vector facility */
+#define VEX_HWCAPS_S390X_MSA5  (1 << 7)  /* Message-security-assistance facility 5 */
+#define VEX_HWCAPS_S390X_MI2   (1 << 8)  /* Miscellaneous-instruction-extensions facility 2 */
+#define VEX_HWCAPS_S390X_LSC2  (1 << 9)  /* Conditional load/store facility2 */
+#define VEX_HWCAPS_S390X_VXE   (1 << 10) /* Vector-enhancements facility */
+#define VEX_HWCAPS_S390X_NNPA  (1 << 11) /* NNPA facility */
+#define VEX_HWCAPS_S390X_DFLT  (1 << 12) /* Deflate-conversion facility */
+#define VEX_HWCAPS_S390X_VXE2  (1 << 13) /* Vector-enhancements facility 2 */
+#define VEX_HWCAPS_S390X_VXD   (1 << 14) /* Vector packed-decimal facility */
+#define VEX_HWCAPS_S390X_MSA8  (1 << 15) /* Message-security-assist extension 8 */
+#define VEX_HWCAPS_S390X_MSA9  (1 << 16) /* Message-security-assist extension 9 */
 
 /* Special value representing all available s390x hwcaps */
-#define VEX_HWCAPS_S390X_ALL   (VEX_HWCAPS_S390X_LDISP | \
-                                VEX_HWCAPS_S390X_EIMM  | \
-                                VEX_HWCAPS_S390X_GIE   | \
-                                VEX_HWCAPS_S390X_DFP   | \
-                                VEX_HWCAPS_S390X_FGX   | \
-                                VEX_HWCAPS_S390X_STFLE | \
-                                VEX_HWCAPS_S390X_STCKF | \
-                                VEX_HWCAPS_S390X_FPEXT | \
-                                VEX_HWCAPS_S390X_LSC   | \
-                                VEX_HWCAPS_S390X_ETF3  | \
-                                VEX_HWCAPS_S390X_ETF2  | \
-                                VEX_HWCAPS_S390X_PFPO  | \
-                                VEX_HWCAPS_S390X_VX    | \
+#define VEX_HWCAPS_S390X_ALL   (VEX_HWCAPS_S390X_VX    | \
                                 VEX_HWCAPS_S390X_MSA5  | \
                                 VEX_HWCAPS_S390X_MI2   | \
                                 VEX_HWCAPS_S390X_LSC2  | \
@@ -210,8 +184,6 @@ typedef
                                 VEX_HWCAPS_S390X_DFLT  | \
                                 VEX_HWCAPS_S390X_VXE2  | \
                                 VEX_HWCAPS_S390X_VXD   | \
-                                VEX_HWCAPS_S390X_MSA   | \
-                                VEX_HWCAPS_S390X_MSA4  | \
                                 VEX_HWCAPS_S390X_MSA8  | \
                                 VEX_HWCAPS_S390X_MSA9)
 
