@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -84,40 +84,19 @@ typedef
       EmWarn_PPC64_redir_overflow,
       EmWarn_PPC64_redir_underflow,
 
-      /* insn specifies a rounding mode other than "according to FPC"
-         which requires the floating point extension facility. But that
-         facility is not available on this host */
-      EmWarn_S390X_fpext_rounding,
-
       /* Various BFP insns have an M4 field containing the
-         IEEE-inexact-exception (XxC) control bit. That bit cannot me modelled
+         IEEE-inexact-exception (XxC) control bit. That bit cannot be modelled
          in VEX and is expected to be zero. */
       EmWarn_S390X_XxC_not_zero,
 
       /* Various DFP insns have an M4 field containing the
-         IEEE-invalid-operation (XiC) control bit. That bit cannot me modelled
+         IEEE-invalid-operation (XiC) control bit. That bit cannot be modelled
          in VEX and is expected to be zero. */
       EmWarn_S390X_XiC_not_zero,
 
-      /* stfle insn is not supported on this host */
-      EmFail_S390X_stfle,
-
-      /* stckf insn is not supported on this host */
-      EmFail_S390X_stckf,
-
-      /* ecag insn is not supported on this host */
-      EmFail_S390X_ecag,
-
       /* pfpo insn is not supported on this host */
       EmFail_S390X_pfpo,
 
-      /* DFP insns are not supported on this host */
-      EmFail_S390X_DFP_insn,
-
-      /* insn needs floating point extension facility which is not
-         available on this host */
-      EmFail_S390X_fpext,
-
       /* GPR 0 contains invalid rounding mode for PFPO instruction */
       EmFail_S390X_invalid_PFPO_rounding_mode,
 
@@ -151,14 +130,6 @@ typedef
          this host */
       EmFail_S390X_vxd,
 
-      /* insn needs message-security assist which is not available on
-         this host */
-      EmFail_S390X_msa,
-
-      /* insn needs message-security-assist extension 4 which is not available
-         on this host */
-      EmFail_S390X_msa4,
-
       /* insn needs message-security-assist extension 8 which is not available
          on this host */
       EmFail_S390X_msa8,
