@@ -16,7 +16,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1094,6 +1094,12 @@ struct _DebugInfo {
       This helps performance a lot during ML_(addLineInfo) etc., which can
       easily be invoked hundreds of thousands of times. */
    DebugInfoMapping* last_rx_map;
+
+#if DARWIN_VERS >= DARWIN_11_00
+   /* Indicate that this debug info was loaded from memory (i.e. DSC)
+      instead than from a file. This means that some data might be missing (e.g. rw data). */
+   Bool from_memory;
+#endif
 };
 
 /* --------------------- functions --------------------- */
