@@ -15,7 +15,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -334,10 +334,6 @@ static const struct auxv *find_auxv(const UWord* sp)
    return (const struct auxv *)sp;
 }
 
-/*
- * @todo PJF Make this multi-platform
- */
-
 /* ----------------------------------------------------------------
 
    This sets up the client's initial stack, containing the args,
@@ -414,7 +410,6 @@ static Addr setup_client_stack(const void*  init_sp,
    Addr client_SP;           /* client stack base (initial SP) */
    Addr clstack_start;       /* client_SP rounded down to nearest page */
    Int i;
-   Bool have_exename;
    Word client_argv;
 
    vg_assert(VG_IS_PAGE_ALIGNED(clstack_end+1));
@@ -435,7 +430,6 @@ static Addr setup_client_stack(const void*  init_sp,
 
    /* first of all, work out how big the client stack will be */
    stringsize   = 0;
-   have_exename = VG_(args_the_exename) != NULL;
 
    /* paste on the extra args if the loader needs them (ie, the #!
       interpreter and its argument) */
@@ -450,9 +444,7 @@ static Addr setup_client_stack(const void*  init_sp,
    }
 
    /* now scan the args we're given... */
-   if (have_exename) {
-      stringsize += VG_(strlen)( VG_(args_the_exename) ) + 1;
-   }
+   stringsize += VG_(strlen)( VG_(args_the_exename) ) + 1;
 
    for (i = 0; i < VG_(sizeXA)( VG_(args_for_client) ); i++) {
       argc++;
@@ -481,17 +473,14 @@ static Addr setup_client_stack(const void*  init_sp,
          break;
       case VKI_AT_CANARYLEN:
          canarylen = cauxv->u.a_val;
-         /*VG_ROUNDUP(stringsize, sizeof(Word));*/
          stringsize += canarylen;
          break;
       case VKI_AT_PAGESIZESLEN:
          pagesizeslen = cauxv->u.a_val;
-         /*VG_ROUNDUP(stringsize, sizeof(Word));*/
          stringsize += pagesizeslen;
          break;
 #if 0
       case VKI_AT_TIMEKEEP:
-         /*VG_ROUNDUP(stringsize, sizeof(Word));*/
          stringsize += sizeof(struct vki_vdso_timehands);
          break;
 #endif
@@ -510,7 +499,7 @@ static Addr setup_client_stack(const void*  init_sp,
    /* OK, now we know how big the client stack is */
    used_stacksize =
       sizeof(Word) +                          /* argc */
-      (have_exename ? sizeof(HChar **) : 0) +  /* argc[0] == exename */
+      sizeof(HChar **) +                      /* argc[0] == exename */
       sizeof(HChar **)*argc +                 /* argv */
       sizeof(HChar **) +                      /* terminal NULL */
       sizeof(HChar **)*envc +                 /* envp */
@@ -527,7 +516,7 @@ static Addr setup_client_stack(const void*  init_sp,
    client_SP = VG_ROUNDDN(client_SP, 16); /* make stack 16 byte aligned */
 
    /* base of the string table (aligned) */
-   stringbase = strtab = (HChar *)clstack_end
+   stringbase = strtab = (HChar *)clstack_end + 1
                          - VG_ROUNDUP(stringsize, sizeof(int));
 
    clstack_start = VG_PGROUNDDN(client_SP);
@@ -645,7 +634,7 @@ static Addr setup_client_stack(const void*  init_sp,
    ptr = (Addr*)client_SP;
 
    /* --- client argc --- */
-   *ptr++ = argc + (have_exename ? 1 : 0);
+   *ptr++ = argc + 1;
 
    /* --- client argv --- */
    client_argv = (Word)ptr;
@@ -656,9 +645,7 @@ static Addr setup_client_stack(const void*  init_sp,
       *ptr++ = (Addr)copy_str(&strtab, info->interp_args);
    }
 
-   if (have_exename) {
-      *ptr++ = (Addr)copy_str(&strtab, VG_(args_the_exename));
-   }
+   *ptr++ = (Addr)copy_str(&strtab, VG_(args_the_exename));
 
    for (i = 0; i < VG_(sizeXA)( VG_(args_for_client) ); i++) {
       *ptr++ = (Addr)copy_str(
@@ -854,6 +841,8 @@ static Addr setup_client_stack(const void*  init_sp,
 
    vg_assert((strtab-stringbase) == stringsize);
 
+   vg_assert((HChar*)auxv < stringbase);
+
    /* client_SP is pointing at client's argc/argv */
 
    if (0) {
