@@ -13,7 +13,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -961,7 +961,7 @@ Addr setup_client_stack( void*  init_sp,
       }
       HChar resolved_name[VKI_PATH_MAX];
       VG_(realpath)(exe_name, resolved_name);
-      VG_(resolved_exename) = VG_(strdup)("initimg-linux.sre.1", resolved_name);
+      VG_(resolved_exename) = VG_(strdup)("initimg-linux.scs.1", resolved_name);
    }
 
    /* client_SP is pointing at client's argc/argv */
