@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1189,6 +1189,8 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY(__NR_statmount,               sys_statmount),               // 457
    LINXY(__NR_listmount,               sys_listmount),               // 458
    LINX_(__NR_mseal,                   sys_mseal),                   // 462
+   LINXY(__NR_file_getattr,            sys_file_getattr),            // 468
+   LINX_(__NR_file_setattr,            sys_file_setattr),            // 469
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) (UInt sysno)
