@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -215,8 +215,6 @@ SysRes sys_set_tls ( ThreadId tid, Addr tlsptr )
    file, but that requires even more macro magic. */
 
 DECL_TEMPLATE (mips_linux, sys_set_thread_area);
-DECL_TEMPLATE (mips_linux, sys_swapon);
-DECL_TEMPLATE (mips_linux, sys_swapoff);
 DECL_TEMPLATE (mips_linux, sys_sethostname);
 DECL_TEMPLATE (mips_linux, sys_reboot);
 DECL_TEMPLATE (mips_linux, sys_cacheflush);
@@ -236,18 +234,6 @@ PRE(sys_sched_rr_get_interval)
    *flags |= SfMayBlock;
 }
 
-PRE(sys_swapon)
-{
-   PRINT("sys_swapon ( %#" FMT_REGWORD "x, %#" FMT_REGWORD "x )", ARG1, ARG2);
-   PRE_REG_READ2(long, "swapon", const void *, path, int, flags);
-}
-
-PRE(sys_swapoff)
-{
-   PRINT("sys_swapoff ( %#" FMT_REGWORD "x )", ARG1);
-   PRE_REG_READ1(long, "swapoff", const void *, path);
-}
-
 /* Very much MIPS specific */
 PRE(sys_cacheflush)
 {
@@ -648,8 +634,8 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_mount, sys_mount),
    LINX_ (__NR_mount_setattr, sys_mount_setattr),
    LINX_ (__NR_umount2, sys_umount),
-   PLAX_ (__NR_swapon, sys_swapon),
-   PLAX_ (__NR_swapoff, sys_swapoff),
+   LINX_ (__NR_swapon, sys_swapon),
+   LINX_ (__NR_swapoff, sys_swapoff),
    PLAX_ (__NR_reboot, sys_reboot),
    PLAX_ (__NR_sethostname, sys_sethostname),
    LINX_ (__NR_setdomainname, sys_setdomainname),
@@ -658,7 +644,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_delete_module, sys_delete_module),
    GENX_ (__NR_get_kernel_syms, sys_ni_syscall),
    GENX_ (__NR_query_module, sys_ni_syscall),
-   LINX_ (__NR_quotactl, sys_quotactl),
+   LINXY (__NR_quotactl, sys_quotactl),
    /* GENX_(__NR_nfsservctl,sys_nfsservctl), */
    GENXY (__NR_getpmsg, sys_getpmsg),
    GENX_ (__NR_putpmsg, sys_putpmsg),
@@ -811,9 +797,13 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_userfaultfd, sys_userfaultfd),
    LINXY (__NR_statmount, sys_statmount),
    LINXY (__NR_listmount, sys_listmount),
+   LINXY(__NR_lsm_get_self_attr, sys_lsm_get_self_attr),
+   LINX_(__NR_lsm_set_self_attr, sys_lsm_set_self_attr),
    LINX_ (__NR_mseal, sys_mseal),
    LINX_ (__NR_futex_waitv, sys_futex_waitv),
-   LINX_ (__NR_quotactl_fd, sys_quotactl_fd),
+   LINXY (__NR_quotactl_fd, sys_quotactl_fd),
+   LINXY (__NR_file_getattr, sys_file_getattr),
+   LINX_ (__NR_file_setattr, sys_file_setattr),
 };
 
 SyscallTableEntry * ML_(get_linux_syscall_entry) ( UInt sysno )
