@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -315,6 +315,7 @@ PRE(sys_fstatat64)
          ARG3);
    PRE_REG_READ3(long, "fstatat64",
                  int, dfd, char *, file_name, struct stat64 *, buf);
+   ML_(fd_at_check_allowed)(SARG1, (const HChar*)ARG2, "fstatat64", tid, status);
    PRE_MEM_RASCIIZ( "fstatat64(file_name)", ARG2 );
    PRE_MEM_WRITE( "fstatat64(buf)", ARG3, sizeof(struct vki_stat64) );
 }
@@ -685,7 +686,7 @@ static SyscallTableEntry syscall_table[] = {
 
    GENX_(__NR_umask,             sys_umask),             // 60
    GENX_(__NR_chroot,            sys_chroot),            // 61
-//..    //   (__NR_ustat,             sys_ustat)              // 62 SVr4 -- deprecated
+   LINXY(__NR_ustat,             sys_ustat),             // 62 SVr4 -- deprecated
    GENXY(__NR_dup2,              sys_dup2),              // 63
    GENX_(__NR_getppid,           sys_getppid),           // 64
 
@@ -715,7 +716,7 @@ static SyscallTableEntry syscall_table[] = {
 //.. 
    GENXY(__NR_readlink,          sys_readlink),          // 85
 //..    //   (__NR_uselib,            sys_uselib),            // 86 */Linux
-//..    //   (__NR_swapon,            sys_swapon),            // 87 */Linux
+   LINX_(__NR_swapon,            sys_swapon),            // 87 */Linux
 //..    //   (__NR_reboot,            sys_reboot),            // 88 */Linux
 //..    //   (__NR_readdir,           old_readdir),           // 89 -- superseded
 
@@ -749,14 +750,14 @@ static SyscallTableEntry syscall_table[] = {
 //..    //   (__NR_vm86old,           sys_vm86old),           // 113 x86/Linux-only
    GENXY(__NR_wait4,             sys_wait4),             // 114
 //.. 
-//..    //   (__NR_swapoff,           sys_swapoff),           // 115 */Linux 
+   LINX_(__NR_swapoff,           sys_swapoff),           // 115 */Linux 
    LINXY(__NR_sysinfo,           sys_sysinfo),           // 116
    LINXY(__NR_ipc,               sys_ipc),               // 117
    GENX_(__NR_fsync,             sys_fsync),             // 118
    PLAX_(__NR_sigreturn,         sys_sigreturn),         // 119 ?/Linux
 //.. 
    LINX_(__NR_clone,             sys_clone),             // 120
-//..    //   (__NR_setdomainname,     sys_setdomainname),     // 121 */*(?)
+   LINX_(__NR_setdomainname,     sys_setdomainname),     // 121
    GENXY(__NR_uname,             sys_newuname),          // 122
 //..    PLAX_(__NR_modify_ldt,        sys_modify_ldt),        // 123
    LINXY(__NR_adjtimex,          sys_adjtimex),          // 124
@@ -769,12 +770,12 @@ static SyscallTableEntry syscall_table[] = {
 //.. 
 //..    // Nb: get_kernel_syms() was removed 2.4-->2.6
 //..    GENX_(__NR_get_kernel_syms,   sys_ni_syscall),        // 130
-//..    LINX_(__NR_quotactl,          sys_quotactl),          // 131
+   LINXY(__NR_quotactl,          sys_quotactl),          // 131
    GENX_(__NR_getpgid,           sys_getpgid),           // 132
    GENX_(__NR_fchdir,            sys_fchdir),            // 133
 //..    //   (__NR_bdflush,           sys_bdflush),           // 134 */Linux
 //.. 
-//..    //   (__NR_sysfs,             sys_sysfs),             // 135 SVr4
+   LINXY(__NR_sysfs,             sys_sysfs),             // 135 SVr4
    LINX_(__NR_personality,       sys_personality),       // 136
 //..    GENX_(__NR_afs_syscall,       sys_ni_syscall),        // 137
    LINX_(__NR_setfsuid,          sys_setfsuid),          // 138
@@ -863,7 +864,7 @@ static SyscallTableEntry syscall_table[] = {
    GENX_(__NR_madvise,           sys_madvise),           // 205
    GENXY(__NR_mincore,           sys_mincore),           // 206
    LINX_(__NR_gettid,            sys_gettid),            // 207
-//..    LINX_(__NR_tkill,             sys_tkill),             // 208 */Linux
+   LINX_(__NR_tkill,             sys_tkill),             // 208 */Linux
    LINX_(__NR_setxattr,          sys_setxattr),          // 209
    LINX_(__NR_lsetxattr,         sys_lsetxattr),         // 210
    LINX_(__NR_fsetxattr,         sys_fsetxattr),         // 211
@@ -901,7 +902,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_epoll_ctl,         sys_epoll_ctl),         // 237
    LINXY(__NR_epoll_wait,        sys_epoll_wait),        // 238
 
-//..    //   (__NR_remap_file_pages,  sys_remap_file_pages),  // 239 */Linux
+   LINX_(__NR_remap_file_pages,  sys_remap_file_pages),  // 239 */Linux
    LINXY(__NR_timer_create,      sys_timer_create),      // 240
    LINXY(__NR_timer_settime,     sys_timer_settime),     // 241
    LINXY(__NR_timer_gettime,     sys_timer_gettime),     // 242
@@ -953,6 +954,8 @@ static SyscallTableEntry syscall_table[] = {
    LINXY(__NR_pselect6,          sys_pselect6),          // 280
    LINXY(__NR_ppoll,             sys_ppoll),             // 281
 
+   LINX_(__NR_splice,            sys_splice),            // 283
+
    LINXY(__NR_openat,            sys_openat),            // 286
    LINX_(__NR_mkdirat,           sys_mkdirat),           // 287
    LINX_(__NR_mknodat,           sys_mknodat),           // 288
@@ -991,6 +994,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_pwritev,           sys_pwritev),          // 321
    LINXY(__NR_rt_tgsigqueueinfo, sys_rt_tgsigqueueinfo),// 322
 
+   LINXY(__NR_prlimit64,         sys_prlimit64),        // 325
    LINXY(__NR_socket,            sys_socket),           // 326
    LINX_(__NR_bind,              sys_bind),             // 327
    LINX_(__NR_connect,           sys_connect),          // 328
@@ -1026,6 +1030,8 @@ static SyscallTableEntry syscall_table[] = {
    LINX_ (__NR_execveat,         sys_execveat),         // 362
 
    LINXY(__NR_userfaultfd,       sys_userfaultfd),      // 364
+   LINX_(__NR_membarrier,        sys_membarrier),       // 365
+
    GENX_(__NR_mlock2,            sys_mlock2),           // 378
    LINX_(__NR_copy_file_range,   sys_copy_file_range),  // 379
    LINX_(__NR_preadv2,           sys_preadv2),          // 380
@@ -1074,13 +1080,24 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_faccessat2,        sys_faccessat2),       // 439
 
    LINXY (__NR_epoll_pwait2,     sys_epoll_pwait2),      // 441
+   LINX_ (__NR_mount_setattr,    sys_mount_setattr),     // 442
+   LINXY (__NR_quotactl_fd,      sys_quotactl_fd),       // 443
 
    LINXY(__NR_landlock_create_ruleset, sys_landlock_create_ruleset), // 444
    LINX_(__NR_landlock_add_rule,       sys_landlock_add_rule),       // 445
    LINX_(__NR_landlock_restrict_self,  sys_landlock_restrict_self),  // 446
 
+   LINX_(__NR_futex_waitv,       sys_futex_waitv),       // 449
    LINXY(__NR_cachestat,         sys_cachestat),         // 451
    LINX_ (__NR_fchmodat2,        sys_fchmodat2),         // 452
+   LINXY (__NR_statmount,        sys_statmount),         // 457
+   LINXY (__NR_listmount,        sys_listmount),         // 458
+   LINXY (__NR_lsm_get_self_attr,sys_lsm_get_self_attr), // 459
+   LINX_ (__NR_lsm_set_self_attr,sys_lsm_set_self_attr), // 460
+   LINXY (__NR_lsm_list_modules, sys_lsm_list_modules),  // 461
+   LINX_ (__NR_mseal,            sys_mseal),             // 462
+   LINXY (__NR_file_getattr,     sys_file_getattr),      // 468
+   LINX_ (__NR_file_setattr,     sys_file_setattr),      // 469
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) ( UInt sysno )
