@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -515,7 +515,7 @@ static SyscallTableEntry syscall_table[] = {
 
    GENXY(__NR_readlink,  sys_readlink),                               // 85
 // ?????(__NR_uselib, ),                                              // 86
-// ?????(__NR_swapon, ),                                              // 87
+   LINX_(__NR_swapon,  sys_swapon),                                   // 87
 // ?????(__NR_reboot, ),                                              // 88
    GENX_(89, sys_ni_syscall), /* unimplemented (by the kernel) */     // 89
 
@@ -549,7 +549,7 @@ static SyscallTableEntry syscall_table[] = {
    GENX_(113, sys_ni_syscall), /* unimplemented (by the kernel) */    // 113
    GENXY(__NR_wait4,  sys_wait4),                                     // 114
 
-// ?????(__NR_swapoff, ),                                             // 115
+   LINX_(__NR_swapoff, sys_swapoff),                                  // 115
    LINXY(__NR_sysinfo,  sys_sysinfo),                                 // 116
    LINXY(__NR_ipc, sys_ipc),                                          // 117
    GENX_(__NR_fsync,  sys_fsync),                                     // 118
@@ -568,7 +568,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_delete_module,  sys_delete_module),                     // 129
 
    GENX_(130, sys_ni_syscall), /* unimplemented (by the kernel) */    // 130
-   LINX_(__NR_quotactl, sys_quotactl),                                // 131
+   LINXY(__NR_quotactl, sys_quotactl),                                // 131
    GENX_(__NR_getpgid,  sys_getpgid),                                 // 132
    GENX_(__NR_fchdir,  sys_fchdir),                                   // 133
 // ?????(__NR_bdflush, ),                                             // 134
@@ -887,7 +887,7 @@ static SyscallTableEntry syscall_table[] = {
 
    LINXY(__NR_epoll_pwait2, sys_epoll_pwait2),                        // 441
    LINX_(__NR_mount_setattr, sys_mount_setattr),                      // 442
-   LINX_(__NR_quotactl_fd, sys_quotactl_fd),                          // 443
+   LINXY(__NR_quotactl_fd, sys_quotactl_fd),                          // 443
 
    LINXY(__NR_landlock_create_ruleset, sys_landlock_create_ruleset),  // 444
    LINX_(__NR_landlock_add_rule,       sys_landlock_add_rule),        // 445
@@ -900,7 +900,12 @@ static SyscallTableEntry syscall_table[] = {
    LINX_ (__NR_fchmodat2, sys_fchmodat2),                             // 452
    LINXY (__NR_statmount, sys_statmount),                             // 457
    LINXY (__NR_listmount, sys_listmount),                             // 458
+   LINXY (__NR_lsm_get_self_attr, sys_lsm_get_self_attr),             // 459
+   LINX_ (__NR_lsm_set_self_attr, sys_lsm_set_self_attr),             // 460
+   LINXY (__NR_lsm_list_modules, sys_lsm_list_modules),               // 461
    LINX_ (__NR_mseal, sys_mseal),                                     // 462
+   LINXY (__NR_file_getattr, sys_file_getattr),                       // 468
+   LINX_ (__NR_file_setattr, sys_file_setattr),                       // 469
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) ( UInt sysno )
