@@ -10,7 +10,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -30,19 +30,6 @@
 #include "config.h"
 #include <sys/syscall.h>
 
-// this is the syscall format used by e.g., libc functions like 'write'
-// this is the one used 99.999% of the time
-// the two others are only for experimental or testing use
-// (but we use them in the scalar tests).
-#define VG_FREEBSD_SYSCALL_STD 0
-// this is the syscall format used by 'syscall'
-#define VG_FREEBSD_SYSCALL0    1
-// this is the syscall format used by '__syscall'
-// it is the same as VG_FREEBSD_SYSCALL0 except that
-// it ensures that 64bit argument alignment is correct
-// that makes no difference for amd64, x86 not sure
-#define VG_FREEBSD_SYSCALL198  2
-
 // From sys/syscall.h
 
 // @todo PJF ugly leading double underscores
