@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1768,7 +1768,8 @@ static void print_results(ThreadId tid, LeakCheckParams* lcp)
       umsg_or_xml(VG_(clo_xml) ?
                   "  <still_reachable>\n"
                   "    <bytes>%'lu%s</bytes>\n"
-                  "    <blocks>%'lu%s</blocks>\n" :
+                  "    <blocks>%'lu%s</blocks>\n"
+                  "  </still_reachable>\n" :
                   "   still reachable: %'lu%s bytes in %'lu%s blocks\n",
                 MC_(bytes_reachable), 
                 DBY (MC_(bytes_reachable), old_bytes_reachable), 
