@@ -8,7 +8,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1236,7 +1236,7 @@ static const char *opcodes[] = {
    "vpks    v1,v2,v3,m4:{1..3},m5:{0,1}", // no spec. exception for m5
    "vpkls   v1,v2,v3,m4:{1..3},m5:{0,1}", // no spec. exception for m5
    "vperm   v1,v2,v3,v4",
-   "vpdi    v1,v2,v3,m4",
+   "vpdi    v1,v2,v3,m4:{0,1,4,5}",       // no spec. exception for m4
 //   "vrep    v1,v3,i2:u16,m4:{0..3}",
    "vrepi   v1,i2:s16,m3:{0..3}",
    "vscef   v1,d12(v2,b2),m3:{0..3}",
